##  4. The Rights of Users
### Object to processing of their Data
Users have the right to object to the processing of their Data if the processing is carried out on a legal basis other than consent. Further details are provided in the dedicated section below.
### Access their Data
Users have the right to learn if Data is being processed by the Data Controller, obtain disclosure regarding certain aspects of the processing, and obtain a copy of the Data undergoing processing.
### Verify and seek rectification
Users have the right to verify the accuracy of their Data and ask for it to be updated or corrected.
### Restrict the processing of their Data
Users have the right, under certain circumstances, to restrict the processing of their Data. In this case, the Data Controller will not process their Data for any purpose other than storing it.
### Have their Personal Data deleted or otherwise removed
Users have the right, under certain circumstances, to obtain the erasure of their Data from the Data Controller. To do so, they shall submit a request to SAP LeanIX Customer Support.
### Receive their Data and have it transferred to another controller
Users have the right to receive their Data in a structured, commonly used and machine-readable format and, if technically feasible, to have it transmitted to another controller without any hindrance.
### Lodge a complaint
Users have the right to bring a claim before their competent data protection authority.
### How to exercise these rights
Any requests to exercise User rights can be directed to the Data Controller through the contact details provided in this document. These requests can be exercised free of charge and will be addressed by the Data Controller as early as possible and always within one month.
